package com.link.core.converter.util;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlTransient;

public class StackTraceBean implements Serializable {
   private static final long serialVersionUID = -6268832239509056276L;
   private String className;
   private String methodName;
   private String fileName;
   private int lineNumber = -1;

   public StackTraceBean() {
   }

   public StackTraceBean(StackTraceElement stackTraceElement) throws IllegalArgumentException {
      if (stackTraceElement == null) {
         throw ExceptionUtil.nullArgument("stackTraceElement");
      } else {
         this.className = stackTraceElement.getClassName();
         this.methodName = stackTraceElement.getMethodName();
         this.fileName = stackTraceElement.getFileName();
         this.lineNumber = stackTraceElement.getLineNumber();
      }
   }

   public StackTraceBean(String className, String methodName, String fileName, int lineNumber) {
      this.className = className;
      this.methodName = methodName;
      this.fileName = fileName;
      this.lineNumber = lineNumber;
   }

   public String getClassName() {
      return this.className;
   }

   public void setClassName(String className) {
      this.className = className;
   }

   public String getMethodName() {
      return this.methodName;
   }

   public void setMethodName(String methodName) {
      this.methodName = methodName;
   }

   public String getFileName() {
      return this.fileName;
   }

   public void setFileName(String fileName) {
      this.fileName = fileName;
   }

   public int getLineNumber() {
      return this.lineNumber;
   }

   public void setLineNumber(int lineNumber) {
      this.lineNumber = lineNumber;
   }

   @XmlTransient
   public boolean isNativeMethod() {
      return this.lineNumber == -2;
   }

   public StackTraceElement toStackTraceElement() {
      return new StackTraceElement(this.className, this.methodName, this.fileName, this.lineNumber);
   }

   public int hashCode() {
      int prime = true;
      int result = 1;
      result = 31 * result + (this.className == null ? 0 : this.className.hashCode());
      result = 31 * result + (this.fileName == null ? 0 : this.fileName.hashCode());
      result = 31 * result + this.lineNumber;
      result = 31 * result + (this.methodName == null ? 0 : this.methodName.hashCode());
      return result;
   }

   public boolean equals(Object obj) {
      if (this == obj) {
         return true;
      } else if (obj == null) {
         return false;
      } else if (this.getClass() != obj.getClass()) {
         return false;
      } else {
         StackTraceBean other = (StackTraceBean)obj;
         if (this.className == null) {
            if (other.className != null) {
               return false;
            }
         } else if (!this.className.equals(other.className)) {
            return false;
         }

         if (this.fileName == null) {
            if (other.fileName != null) {
               return false;
            }
         } else if (!this.fileName.equals(other.fileName)) {
            return false;
         }

         if (this.lineNumber != other.lineNumber) {
            return false;
         } else {
            if (this.methodName == null) {
               if (other.methodName != null) {
                  return false;
               }
            } else if (!this.methodName.equals(other.methodName)) {
               return false;
            }

            return true;
         }
      }
   }

   public String toString() {
      StringBuffer sb = new StringBuffer();
      sb.append(this.className);
      sb.append('.');
      sb.append(this.methodName);
      sb.append('(');
      if (this.isNativeMethod()) {
         sb.append("Native Method");
      } else if (this.fileName != null && this.lineNumber >= 0) {
         sb.append(this.fileName);
         sb.append(':');
         sb.append(this.lineNumber);
      } else if (this.fileName != null) {
         sb.append(this.fileName);
      } else {
         sb.append("Unknown Source");
      }

      sb.append(')');
      return sb.toString();
   }

   public StackTraceBean clone() {
      StackTraceBean other = new StackTraceBean();
      other.className = this.className;
      other.methodName = this.methodName;
      other.fileName = this.fileName;
      other.lineNumber = this.lineNumber;
      return other;
   }
}
